@@ -14,9 +14,9 @@
 from lxml import etree  # fast and furious xml library
 
 from eoleaaf.util import modif_fields, MinimalSQLGenerator, pwgen, log, db, \
-                 parse_multi, get_new_id
+                 parse_multi, get_new_id, gen_user_login
 
-from eoleaaf.miscutil import eleve_id, eleve_uid_and_password, classes_for_one_eleve, \
+from eoleaaf.miscutil import eleve_id, classes_for_one_eleve, \
                                 groupe_eleve
 
 
@@ -117,10 +117,12 @@ def parse_aaf_eleves(eleve_file):
             continue
         #**Attention** identifier/id == ENTPersonJointure
         eleve = eleve_id(televe)
-        eleve, uid = eleve_uid_and_password(eleve)
+        uid = eleve['uid'] = get_new_id()
+        eleve['userPassword'] = pwgen()
         for attr in televe.findall('attributes/attr'):
             balise, vals = parse_multi(attr)
             eleve[balise] = vals
+        eleve['ENTPersonLogin'] = gen_user_login(eleve['sn'], eleve['givenName'], uid, 'eleve', eleve['id'])
         # ajout de l'eleve a la classe et au groupe
         classes_for_one_eleve(eleve, classes_buffer, uid)
         groupe_eleve(eleve, groupes_buffer, uid)
@@ -224,10 +226,10 @@ def parse_aaf_responsables(responsables_file):
         for attr in tresp.findall('attributes/attr'):
             balise, vals = parse_multi(attr)
             responsable[balise] = vals
-
         # new calculated uid and password
         responsable['uid'] = get_new_id()
         responsable['userPassword'] = pwgen()
+        responsable['ENTPersonLogin'] = gen_user_login(responsable['sn'], responsable['givenName'], responsable['uid'], 'responsable', responsable['id'])
         # ____________________________________________________________
         # remplissage des élèves associé au responsable
         # à partir des inforamtions bufferisées
@@ -306,6 +308,12 @@ def parse_aaf_profs(profs_file):
         #cf. Annexe 4 (Alimentation depuis le SI MEN) version 4.2
         if professeur['PersEducNatPresenceDevantEleves'] == 'O' or \
            '$DOC$' in professeur['ENTPersonFonctions']:
+            usertype = 'enseignant'
+        else:
+            usertype = 'administratif'
+        professeur['ENTPersonLogin'] = gen_user_login(professeur['sn'], professeur['givenName'], professeur['uid'], usertype, professeur['id'])
+
+        if usertype == 'enseignant':
             # c'est un enseignant
             if maj_mode:
                 # il faut aller voir dans la base si les champs n'existent pas
